==> aws-cdk-lib-2.225.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerAddonSubscriptionReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerAddonSubscription resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerAddonSubscriptionReference mailManagerAddonSubscriptionReference = MailManagerAddonSubscriptionReference.builder()
 *         .addonSubscriptionId("addonSubscriptionId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-11-17T14:41:04.000Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerAddonSubscriptionReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerAddonSubscriptionReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerAddonSubscriptionReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The AddonSubscriptionId of the MailManagerAddonSubscription resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAddonSubscriptionId();

    /**
     * @return a {@link Builder} of {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerAddonSubscriptionReference> {
        java.lang.String addonSubscriptionId;

        /**
         * Sets the value of {@link MailManagerAddonSubscriptionReference#getAddonSubscriptionId}
         * @param addonSubscriptionId The AddonSubscriptionId of the MailManagerAddonSubscription resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder addonSubscriptionId(java.lang.String addonSubscriptionId) {
            this.addonSubscriptionId = addonSubscriptionId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerAddonSubscriptionReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerAddonSubscriptionReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerAddonSubscriptionReference {
        private final java.lang.String addonSubscriptionId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addonSubscriptionId = software.amazon.jsii.Kernel.get(this, "addonSubscriptionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addonSubscriptionId = java.util.Objects.requireNonNull(builder.addonSubscriptionId, "addonSubscriptionId is required");
        }

        @Override
        public final java.lang.String getAddonSubscriptionId() {
            return this.addonSubscriptionId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("addonSubscriptionId", om.valueToTree(this.getAddonSubscriptionId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerAddonSubscriptionReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerAddonSubscriptionReference.Jsii$Proxy that = (MailManagerAddonSubscriptionReference.Jsii$Proxy) o;

            return this.addonSubscriptionId.equals(that.addonSubscriptionId);
        }

        @Override
        public final int hashCode() {
            int result = this.addonSubscriptionId.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.231.0-sources.jar: software/amazon/awscdk/interfaces/ses/MailManagerAddonSubscriptionReference.java <==
package software.amazon.awscdk.interfaces.ses;

/**
 * A reference to a MailManagerAddonSubscription resource.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.interfaces.ses.*;
 * MailManagerAddonSubscriptionReference mailManagerAddonSubscriptionReference = MailManagerAddonSubscriptionReference.builder()
 *         .addonSubscriptionArn("addonSubscriptionArn")
 *         .addonSubscriptionId("addonSubscriptionId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.119.0 (build 1634eac)", date = "2025-12-01T16:02:33.209Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.interfaces.aws_ses.MailManagerAddonSubscriptionReference")
@software.amazon.jsii.Jsii.Proxy(MailManagerAddonSubscriptionReference.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MailManagerAddonSubscriptionReference extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the MailManagerAddonSubscription resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAddonSubscriptionArn();

    /**
     * The AddonSubscriptionId of the MailManagerAddonSubscription resource.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getAddonSubscriptionId();

    /**
     * @return a {@link Builder} of {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MailManagerAddonSubscriptionReference> {
        java.lang.String addonSubscriptionArn;
        java.lang.String addonSubscriptionId;

        /**
         * Sets the value of {@link MailManagerAddonSubscriptionReference#getAddonSubscriptionArn}
         * @param addonSubscriptionArn The ARN of the MailManagerAddonSubscription resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder addonSubscriptionArn(java.lang.String addonSubscriptionArn) {
            this.addonSubscriptionArn = addonSubscriptionArn;
            return this;
        }

        /**
         * Sets the value of {@link MailManagerAddonSubscriptionReference#getAddonSubscriptionId}
         * @param addonSubscriptionId The AddonSubscriptionId of the MailManagerAddonSubscription resource. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder addonSubscriptionId(java.lang.String addonSubscriptionId) {
            this.addonSubscriptionId = addonSubscriptionId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MailManagerAddonSubscriptionReference}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MailManagerAddonSubscriptionReference build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MailManagerAddonSubscriptionReference}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MailManagerAddonSubscriptionReference {
        private final java.lang.String addonSubscriptionArn;
        private final java.lang.String addonSubscriptionId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addonSubscriptionArn = software.amazon.jsii.Kernel.get(this, "addonSubscriptionArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.addonSubscriptionId = software.amazon.jsii.Kernel.get(this, "addonSubscriptionId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addonSubscriptionArn = java.util.Objects.requireNonNull(builder.addonSubscriptionArn, "addonSubscriptionArn is required");
            this.addonSubscriptionId = java.util.Objects.requireNonNull(builder.addonSubscriptionId, "addonSubscriptionId is required");
        }

        @Override
        public final java.lang.String getAddonSubscriptionArn() {
            return this.addonSubscriptionArn;
        }

        @Override
        public final java.lang.String getAddonSubscriptionId() {
            return this.addonSubscriptionId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("addonSubscriptionArn", om.valueToTree(this.getAddonSubscriptionArn()));
            data.set("addonSubscriptionId", om.valueToTree(this.getAddonSubscriptionId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.interfaces.aws_ses.MailManagerAddonSubscriptionReference"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MailManagerAddonSubscriptionReference.Jsii$Proxy that = (MailManagerAddonSubscriptionReference.Jsii$Proxy) o;

            if (!addonSubscriptionArn.equals(that.addonSubscriptionArn)) return false;
            return this.addonSubscriptionId.equals(that.addonSubscriptionId);
        }

        @Override
        public final int hashCode() {
            int result = this.addonSubscriptionArn.hashCode();
            result = 31 * result + (this.addonSubscriptionId.hashCode());
            return result;
        }
    }
}
